rectangle = {}
rectangle.__index = rectangle


-- use: ground1 = rectangle.new("static", "rectangle", x, y, width, height)
rectangle.new = function(body_type, x, y, width, height)
	local self = setmetatable({}, rectangle)
	
	self.body_type = body_type
	self.x, self.y = x, y
	self.width, self.height = width, height
	self.collision_type = nil -- to be changed later...
	
	-- body(important)
	self.body = lp.newBody(world, self.x, self.y, self.body_type)
	-- shape(important)
	self.shape = lp.newRectangleShape(self.width, self.height)
	-- fixture(important)
	self.fixture = lp.newFixture(self.body, self.shape)
	
	---
	
	-- "set" methods
	-- use: static:set_collision_type("ceiling")
	function self:set_collision_type(str)
		-- note: not part of "box2d" api
		-- "ceiling", "wall", or "floor" types
		self.collision_type = str
	end
	
	function self:set_angle(value)
		self.body:setAngle(math.floor(math.rad(value)))
	end
	
	function self:can_rotate(bool) -- true or false
		-- whether this body can rotate or not
		self.body:isFixedRotation(bool)
	end
	
	---
	
	-- "get" methods
	function self:get_collision_type()
		local str = "(No type specified)"
		
		if(self.collision_type ~= nil) then
			return collision_type
		else
			return str
		end
	end
	
	function self:get_x()
		return math.floor(self.shape:getX())
	end
	
	function self:get_y()
		return math.floor(self.shape:getY())
	end
	
	-- returns the angle of the "body"
	function self:get_angle()
		return math.floor(math.rad(self.body:getAngle()))
	end
	
	function self:get_child_count()
		return self.shape:getChildCount()
	end
	
	function self:get_bounding_box(i)
		return self.fixture:getBoundingBox(i)
	end
	
	function self:get_aabb(tx, ty, tr, i)
		return self.shape:computeAABB(tx, ty, tr, i)
	end
	
	function self:get_shape_type()
		return self.shape:getType()
	end
	
	function self:get_width()
		return self.width
	end
	
	function self:get_height()
		return self.height
	end
	
	-- touching (imortant: test if this works for collision)
	-- ex: if(not self:is_touching(tx, ty, tr, x, y)) then ... end
	function self:is_point_touching(tx, ty, tr, x, y)
		return self.shape:testPoint(tx, ty, tr, x, y)
	end
	
	return self
end

function rectangle:draw()
	lg.setColor(186, 130, 255, 255)
	lg.polygon("fill", self.body:getWorldPoints(self.shape:getPoints()))
	--lg.rectangle("fill", math.floor(self.body:getX()), math.floor(self.body:getY()), self.width, self.height)
end